Skip to contents

Creation of a Supervisor for handling regulation in a model

Usage

CreateSupervisor(InputsModel, TimeStep = 1L)

Arguments

InputsModel

[object of type GRiwrmInputsModel] inputs of the model

TimeStep

integer number of time steps between each supervision

Value

A Supervisor object which is an environment containing all the necessary variables to run a supervised simulation, such as:

  • DatesR base::POSIXct: vector of date from InputsModel

  • InputsModel: a copy of InputsModel provided by CreateInputsModel.GRiwrm

  • griwrm: a copy of griwrm provided by CreateGRiwrm

  • Controllers list: list of the controllers used in the supervised simulation (See CreateController)

  • idx.output integer: index of the current time step output in the modeled series (updated during simulation)

  • idx.output_previous integer: index of the previous output time step

  • ts.date base::POSIXct: date/time of the current time step for controller calculations

  • ts.index0 integer: index of the time step preceding the start of the simulation period

  • controller.id character: identifier of the current controller being applied

Details

See RunModel.Supervisor and vignettes for examples of use.