Creation of a Supervisor for handling regulation in a model
Source:R/CreateSupervisor.R
CreateSupervisor.RdCreation of a Supervisor for handling regulation in a model
Arguments
- InputsModel
[object of type
GRiwrmInputsModel] inputs of the model- TimeStep
integer number of time steps between each supervision
Value
A Supervisor object which is an environment containing all the necessary variables to run a supervised simulation, such as:
DatesRbase::POSIXct: vector of date fromInputsModelInputsModel: a copy ofInputsModelprovided by CreateInputsModel.GRiwrmgriwrm: a copy ofgriwrmprovided by CreateGRiwrmControllerslist: list of the controllers used in the supervised simulation (See CreateController)idx.outputinteger: index of the current time step output in the modeled series (updated during simulation)idx.output_previousinteger: index of the previous output time stepts.datebase::POSIXct: date/time of the current time step for controller calculationsts.index0integer: index of the time step preceding the start of the simulation periodcontroller.idcharacter: identifier of the current controller being applied
Details
See RunModel.Supervisor and vignettes for examples of use.